@@ -29,7 +29,7 @@ class TestCycleService:
 
     @classmethod
     def get_run_env(cls):
-        env = os.getenv('CI_COMMIT_BRANCH', '') or os.getenv('ENV', '') or os.getenv('ENVIRONMENT', '')
+        env = os.getenv('ENV', '') or os.getenv('ENVIRONMENT', '') or os.getenv('CI_COMMIT_BRANCH', '')
         env = str(env).lower()
         if not env:
             env = 'local'
